@@ -7,6 +7,7 @@ from . import (
     rev5,
     rev6,
     rev7,
+    rev8,
 )
 
 revisions = {
@@ -18,4 +19,5 @@ revisions = {
     5: rev5,
     6: rev6,
     7: rev7,
+    8: rev8,
 }
